@@ -10,12 +10,13 @@ use File::Find 'find';
 use Mojo::Server::Morbo;
 use Mojo::File 'path';
 
-our $VERSION = '1.01'; # VERSION
+our $VERSION = '1.02'; # VERSION
 
 sub conf ($conf) {
-    my $conf_app = Config::App->find;
+    my $conf_app   = Config::App->find;
+    my $mojo_linda = ($conf_app) ? $conf_app->get( qw( mojolicious linda ) ) : {};
 
-    $conf->{$_}  //= $conf_app->{mojolicious}{linda}{$_} for ( qw( silent app mode backend ) );
+    $conf->{$_}  //= $mojo_linda->{$_} for ( qw( silent app mode backend ) );
     $conf->{app} //= $ARGV[0] || do {
         my $match;
         for my $file ( path('.')->list_tree->to_array->@* ) {
@@ -32,7 +33,7 @@ sub conf ($conf) {
     };
 
     for my $name ( qw( listen watch ) ) {
-        my %hash = map { $_ => 1 } $conf->{$name}->@*, $conf->{mojolicious}{linda}{$name}->@*;
+        my %hash = map { $_ => 1 } $conf->{$name}->@*, $mojo_linda->{$name}->@*;
         $conf->{$name} = [ keys %hash ];
     }
 
@@ -91,7 +92,7 @@ MojoX::Linda - Plausibly helpful (and probably drunk) wrapper around morbo
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =for markdown [![test](https://github.com/gryphonshafer/MojoX-Linda/workflows/test/badge.svg)](https://github.com/gryphonshafer/MojoX-Linda/actions?query=workflow%3Atest)
 [![codecov](https://codecov.io/gh/gryphonshafer/MojoX-Linda/graph/badge.svg)](https://codecov.io/gh/gryphonshafer/MojoX-Linda)
